@@ -8,7 +8,7 @@ _ = gettext.gettext
 CLUSTER_NAME=_("Cluster Name: %s")
 CLUSTER_POPULATION=_("Number of Members: %d")
 DLM_TYPE=_("Locking Type: Distributed")
-GULM_TYPE=_("Locking Type: GuLM")
+GULM_TYPE=_("Locking Type: GULM")
 LOCKSERVER=_("Lock Server:")
 CONFIG_VERSION=_("Config Version")
 MCAST_MODE=_("Cluster Manager using Multicast Mode. \n   Multicast Address: %s")
@@ -29,7 +29,7 @@ class Cluster(TagObject):
     isMulticast = False
     mcast_address = ""
 
-    stringbuf = CLUSTER_NAME % self.getAttribute("name") + "\n"
+    stringbuf = CLUSTER_NAME % self.getNameAlias() + "\n"
 
     stringbuf = stringbuf + CONFIG_VERSION + ": " + self.getConfigVersion() + "\n"
 
@@ -106,6 +106,15 @@ class Cluster(TagObject):
     self.addAttribute("config_version", str(intversion))
     #self.is_cfg_version_dirty = True
 
+  def getNameAlias(self):
+    alias = self.getAttribute("alias")
+    if alias == None:
+      name = self.getAttribute("name")
+      self.addAttribute("alias", name)
+      return self.getAttribute("alias")
+    else:
+      return alias
+
   #def addAttribute(self, name, value):
   #  if name == "config_version":
   #    cfg = self.getAttribute("config_version")
