@@ -7,6 +7,7 @@ __author__ = 'Jim Parsons (jparsons@redhat.com)'
 import string
 import os
 import gobject
+import cgi
 
 import gettext
 _ = gettext.gettext
@@ -367,7 +368,7 @@ class ConfigTabController:
     fptr = self.model_builder.getFenceDaemonPtr()
 
     #set fields for edit
-    name = cptr.getName()
+    name = cptr.getNameAlias()
     self.clustername.set_text(name)
     self.config_version.set_text(cptr.getConfigVersion())
 
@@ -428,7 +429,7 @@ class ConfigTabController:
         self.post_fail.select_region(0, -1)
         return
 
-    cptr.addAttribute("name",name)
+    cptr.addAttribute("alias",name)
     cptr.setConfigVersion(version)
 
     if postjoin.strip() != "":
@@ -486,14 +487,14 @@ class ConfigTabController:
     treemodel.clear()
 
     node_iter = treemodel.append(None)
-    node_str = "<span size=\"11000\"><b>" + nd.getName() + "</b></span>"
+    node_str = "<span size=\"11000\"><b>" + cgi.escape(nd.getName()) + "</b></span>"
     treemodel.set(node_iter, FENCE_PIX_COL, self.node_pixbuf,
                              FENCE_NAME_COL, node_str,
                              FENCE_TYPE_COL, F_NODE_TYPE,
                              FENCE_OBJ_COL, nd)
 
     self.fence_panel_label.set_use_markup(True)
-    self.fence_panel_label.set_markup(FENCE_PANEL_LABEL % nd.getName())
+    self.fence_panel_label.set_markup(FENCE_PANEL_LABEL % (cgi.escape(nd.getName())))
     for fence_level in nd.getFenceLevels():
       flevel_iter = treemodel.append(node_iter)
       flevel_substr = FENCE_LEVEL % level_index
@@ -501,7 +502,7 @@ class ConfigTabController:
       ##level names
       fence_level.addAttribute("name",str(level_index))
       level_index = level_index + 1
-      flevel_str = "<span size=\"11000\"><b>" + flevel_substr + "</b></span>"
+      flevel_str = "<span size=\"11000\"><b>" + cgi.escape(flevel_substr) + "</b></span>"
       treemodel.set(flevel_iter, FENCE_NAME_COL, flevel_str,
                                  FENCE_TYPE_COL, F_LEVEL_TYPE,
                                  FENCE_OBJ_COL, fence_level )
@@ -509,7 +510,7 @@ class ConfigTabController:
       fences = fence_level.getChildren()
       for fence in fences:
         fence_iter = treemodel.append(flevel_iter)
-        fence_str = "<span size=\"11000\"><b>" + fence.getName() + "</b></span>"
+        fence_str = "<span size=\"11000\"><b>" + cgi.escape(fence.getName()) + "</b></span>"
         treemodel.set(fence_iter, FENCE_PIX_COL, self.fence_pixbuf,
                                   FENCE_NAME_COL, fence_str,
                                   FENCE_TYPE_COL, F_FENCE_TYPE,
@@ -641,6 +642,15 @@ class ConfigTabController:
           f_obj.addAttribute(k,attrlist[k])
         self.prep_fence_panel(nd)
         self.fi_panel.hide()
+
+        #special case for drac/mc...if modulename is removed, attr must be as well
+        if agent_type == "fence_drac":
+          try:
+            check_var = attrlist["modulename"]
+            if check_var == "":
+              f_obj.removeAttribute("modulename") #This rm's any old modulename
+          except KeyError, e:
+            pass    #no attr, no worries
  
 
     self.model_builder.setModified()
@@ -717,7 +727,10 @@ class ConfigTabController:
       self.fi_optionmenu_hash[counter] = fd.getName()
       self.fi_agent_hash[fd.getName()] = fd.getAgentType()
       self.fi_prettyname_hash[counter] = pretty_name_hash[fd.getAgentType()]
-      m = gtk.MenuItem(fd.getName())
+      normalized_name = fd.getName()
+      normalized_name = normalized_name.replace('_','__')
+      m = gtk.MenuItem(normalized_name)
+      # m = gtk.MenuItem(fd.getName())
       counter = counter + 1
       m.show()
       menu.append(m)
@@ -1176,7 +1189,6 @@ class ConfigTabController:
     self.model_builder.setModified()
 
   def prep_fd_options(self):
-   
     menu = gtk.Menu() 
     #make two hashes here - one for idx -> agent and one for 
     pretty_name_hash = self.fence_handler.getFENCE_OPTS()
