@@ -1,4 +1,5 @@
 import os
+from glob import glob
 import gtk
 import gtk.glade
 from ValidationError import ValidationError
@@ -16,6 +17,7 @@ FD_PROVIDE_CSERVER = _("A cserver address must be provided for this Egenera Fenc
 FD_PROVIDE_IP = _("An IP address must be provided for this Fence Device")
 FD_PROVIDE_LOGIN = _("A login name must be provided for this Fence Device")
 FD_PROVIDE_PASSWD = _("A password must be provided for this Fence Device")
+FD_PROVIDE_DEVICE = _("A device path must be provided for this Fence Device")
 FI_PROVIDE_XCATNODENAME = _("An xCAT Nodename must be provided for this Fence")
 FI_PROVIDE_SWITCH = _("A switch address must be provided for this Fence")
 FI_PROVIDE_PORT = _("A port value must be provided for this Fence")
@@ -24,6 +26,7 @@ FI_PROVIDE_DOMAIN = _("A Domain must be specified for this Fence")
 FI_PROVIDE_IPADDRESS = _("An IP address must be provided for this Fence")
 FI_PROVIDE_ELPAN = _("A LPAN value must be provided for this Egenera Fence")
 FI_PROVIDE_EPSERVER = _("A PServer value must be provided for this Egenera Fence")
+FI_PROVIDE_MODULENAME = _("A Module Name must be provided for this DRAC/MC Fence. If you do not wish to use DRAC/MC, uncheck the checkbox.")
 
 ILLEGAL_CHARS_REPLACED = _("Illegal characters were replaced by underscores. Feel free to set a new value.")
 ILLEGAL_CHARS = [':', ' ']
@@ -42,48 +45,60 @@ ILLEGAL_CHARS = [':', ' ']
 #forms to set_text and to check.
 
 FENCE_OPTS = {"fence_apc":_("APC Power Device"),
+              "fence_apc_snmp":_("APC Power Device (SNMP)"),
               "fence_wti":_("WTI Power Device"),
+              "fence_rps10":("RPS10 Serial Switch"),
               "fence_brocade":_("Brocade Switch"),
               "fence_vixel":_("Vixel SAN Switch"),
               "fence_gnbd":_("Global Network Block Device"),
               "fence_ilo":_("HP ILO Device"),
+              "fence_rsa":_("IBM RSA II Device"),
               "fence_sanbox2":_("QLogic SANBox2"),
               "fence_bladecenter":_("IBM Blade Center"),
               "fence_mcdata":_("McDATA SAN Switch"),
               "fence_egenera":_("Egenera SAN Controller"),
               "fence_bullpap":_("Bull PAP"),
               "fence_drac":_("DRAC"),
+              "fence_rsa":_("RSA II"),
               "fence_ipmilan":_("IPMI Lan"),
               "fence_manual":_("Manual Fencing") }
 
 FENCE_FD_ATTRS = {"fence_apc":["name","ipaddr","login","passwd"],
+              "fence_apc_snmp":["name","ipaddr","login","passwd"],
               "fence_wti":["name","ipaddr","passwd"],
+              "fence_rps10":["name","device","port"],
               "fence_brocade":["name","ipaddr","login","passwd"],
               "fence_vixel":["name","ipaddr","passwd"],
               "fence_gnbd":["name","servers"],
               "fence_ilo":["name","hostname","login","passwd"],
+              "fence_rsa":["name","hostname","login","passwd"],
               "fence_sanbox2":["name","ipaddr","login","passwd"],
               "fence_bladecenter":["name","ipaddr","login","passwd"],
               "fence_mcdata":["name","ipaddr","login","passwd"],
               "fence_egenera":["name","cserver"],
-              "fence_ipmilan":["name","ipaddr","login","passwd"],
+              "fence_ipmilan":["name","ipaddr","login","passwd","auth"],
+              "fence_rsa":["name","ipaddr","login","passwd"],
               "fence_bullpap":["name","ipaddr","login","passwd"],
               "fence_drac":["name","ipaddr","login","passwd"],
               "fence_manual":["name"] }
 
 FENCE_FI_ATTRS = {"fence_apc":["port","switch"],
+              "fence_apc_snmp":["port","switch"],
               "fence_wti":["port"],
+              "fence_rps10":[],
               "fence_brocade":["port"],
               "fence_vixel":["port"],
               "fence_gnbd":[],
               "fence_ilo":[],
+              "fence_rsa":[],
               "fence_sanbox2":["port"],
               "fence_bladecenter":["blade"],
               "fence_mcdata":["port"],
               "fence_egenera":["lpan","pserver"],
               "fence_ipmilan":[],
               "fence_bullpap":["domain"],
-              "fence_drac":[],
+              "fence_drac":["modulename"],
+              "fence_rsa":[],
               "fence_manual":[] }
 
 PRETTY_NAME_ATTRS = {"port":_("Port"),
@@ -96,11 +111,14 @@ PRETTY_NAME_ATTRS = {"port":_("Port"),
                      "login":_("Login"),
                      "passwd":_("Password"),
                      "name":_("Name"),
+                     "device":_("Device"),
                      "server":_("Server"),
                      "servers":_("Servers"),
                      "domain":_("Domain"),
                      "hostname":_("Hostname"),
                      "path":_("Path"),
+                     "auth":_("Auth Type"),
+                     "modulename":_("Module Name"),
                      "cserver":_("CServer") }  
 
 class FenceHandler:
@@ -115,6 +133,12 @@ class FenceHandler:
     #gtk.glade.bindtextdomain(PROGNAME)
     self.fence_xml = gtk.glade.XML (gladepath, domain="NULL")
 
+	# hack!
+    if not glob('/usr/share/snmp/mibs/powernet*.mib'):
+        del FENCE_OPTS['fence_apc_snmp']
+        del FENCE_FD_ATTRS['fence_apc_snmp']
+        del FENCE_FI_ATTRS['fence_apc_snmp']
+
     #Generate hash table for agent --> fence instance form
     self.fi_hash = { }
     fence_opt_keys = FENCE_OPTS.keys()
@@ -153,12 +177,16 @@ class FenceHandler:
     #self.fence_xml.get_widget('fi_wti').show()
 
     self.fi_populate = {"fence_apc":self.pop_apc,
+              "fence_apc_snmp":self.pop_apc_snmp,
               "fence_wti":self.pop_wti,
+              "fence_rps10":self.pop_rps10,
               "fence_brocade":self.pop_brocade,
               "fence_vixel":self.pop_vixel,
               "fence_gnbd":self.pop_gnbd,
               "fence_ilo":self.pop_ilo,
+              "fence_rsa":self.pop_rsa,
               "fence_drac":self.pop_drac,
+              "fence_rsa":self.pop_rsa,
               "fence_sanbox2":self.pop_sanbox2,
               "fence_bladecenter":self.pop_bladecenter,
               "fence_mcdata":self.pop_mcdata,
@@ -168,12 +196,16 @@ class FenceHandler:
               "fence_manual":self.pop_manual }
 
     self.fd_populate = {"fence_apc":self.pop_apc_fd,
+              "fence_apc_snmp":self.pop_apc_snmp_fd,
               "fence_wti":self.pop_wti_fd,
+              "fence_rps10":self.pop_rps10_fd,
               "fence_brocade":self.pop_brocade_fd,
               "fence_vixel":self.pop_vixel_fd,
               "fence_gnbd":self.pop_gnbd_fd,
               "fence_ilo":self.pop_ilo_fd,
+              "fence_rsa":self.pop_rsa_fd,
               "fence_drac":self.pop_drac_fd,
+              "fence_rsa":self.pop_rsa_fd,
               "fence_sanbox2":self.pop_sanbox2_fd,
               "fence_bladecenter":self.pop_bladecenter_fd,
               "fence_mcdata":self.pop_mcdata_fd,
@@ -183,12 +215,16 @@ class FenceHandler:
               "fence_manual":self.pop_manual_fd }
 
     self.fi_validate = {"fence_apc":self.val_apc,
+              "fence_apc_snmp":self.val_apc_snmp,
               "fence_wti":self.val_wti,
+              "fence_rps10":self.val_rps10,
               "fence_brocade":self.val_brocade,
               "fence_vixel":self.val_vixel,
               "fence_gnbd":self.val_gnbd,
               "fence_ilo":self.val_ilo,
+              "fence_rsa":self.val_rsa,
               "fence_drac":self.val_drac,
+              "fence_rsa":self.val_rsa,
               "fence_sanbox2":self.val_sanbox2,
               "fence_bladecenter":self.val_bladecenter,
               "fence_mcdata":self.val_mcdata,
@@ -198,12 +234,16 @@ class FenceHandler:
               "fence_manual":self.val_manual }
 
     self.fd_validate = {"fence_apc":self.val_apc_fd,
+              "fence_apc_snmp":self.val_apc_snmp_fd,
               "fence_wti":self.val_wti_fd,
+              "fence_rps10":self.val_rps10_fd,
               "fence_brocade":self.val_brocade_fd,
               "fence_vixel":self.val_vixel_fd,
               "fence_gnbd":self.val_gnbd_fd,
               "fence_ilo":self.val_ilo_fd,
+              "fence_rsa":self.val_rsa_fd,
               "fence_drac":self.val_drac_fd,
+              "fence_rsa":self.val_rsa_fd,
               "fence_sanbox2":self.val_sanbox2_fd,
               "fence_bladecenter":self.val_bladecenter_fd,
               "fence_mcdata":self.val_mcdata_fd,
@@ -229,17 +269,39 @@ class FenceHandler:
   def pop_apc(self, attrs):
     self.apc_port.set_text(attrs["port"]) 
     self.apc_switch.set_text(attrs["switch"]) 
+
+  def pop_apc_snmp(self, attrs):
+    self.apc_snmp_port.set_text(attrs["port"])
+    self.apc_snmp_switch.set_text(attrs["switch"]) 
  
   def pop_wti(self, attrs):
     self.wti_port.set_text(attrs["port"])
  
+  def pop_rps10(self, attrs):
+    pass
+
   def pop_brocade(self, attrs):
     self.brocade_port.set_text(attrs["port"])
  
   def pop_ilo(self, attrs):
     pass
  
+  def pop_rsa(self, attrs):
+    pass
+
   def pop_drac(self, attrs):
+    try:
+      self.drac_modulename.set_sensitive(True)
+      self.drac_modulename.set_text(attrs["modulename"])
+      self.drac_mc_cbox.set_active(True)
+      self.drac_modname_label.set_sensitive(True)
+    except KeyError, e:
+      self.drac_mc_cbox.set_active(False)
+      self.drac_modulename.set_text("")
+      self.drac_modulename.set_sensitive(False)
+      self.drac_modname_label.set_sensitive(False)
+ 
+  def pop_rsa(self, attrs):
     pass
  
   def pop_vixel(self, attrs):
@@ -273,6 +335,8 @@ class FenceHandler:
   def clear_fi_forms(self):
     self.apc_port.set_text("") 
     self.apc_switch.set_text("") 
+    self.apc_snmp_port.set_text("") 
+    self.apc_snmp_switch.set_text("") 
     self.wti_port.set_text("") 
     self.brocade_port.set_text("")
     self.vixel_port.set_text("")
@@ -283,15 +347,28 @@ class FenceHandler:
     self.egenera_pserver.set_text("")
     self.bullpap_domain.set_text("")
 
+    #handle drac/mc checkbox
+    self.drac_mc_cbox.set_active(False)
+    self.drac_modulename.set_text("")
+    self.drac_modulename.set_sensitive(False)
+    self.drac_modname_label.set_sensitive(False)
+
 
   def clear_fd_forms(self):
     self.apc_fd_name.set_text("") 
     self.apc_fd_ip.set_text("")
     self.apc_fd_login.set_text("")
     self.apc_fd_passwd.set_text("")
+    self.apc_snmp_fd_name.set_text("") 
+    self.apc_snmp_fd_ip.set_text("")
+    self.apc_snmp_fd_login.set_text("")
+    self.apc_snmp_fd_passwd.set_text("")
     self.wti_fd_ip.set_text("")
     self.wti_fd_name.set_text("")
     self.wti_fd_passwd.set_text("")
+    self.rps10_fd_name.set_text("")
+    self.rps10_fd_device.set_text("")
+    self.rps10_fd_port.set_text("")
     self.brocade_fd_name.set_text("")
     self.brocade_fd_ip.set_text("")
     self.brocade_fd_login.set_text("")
@@ -300,10 +377,18 @@ class FenceHandler:
     self.ilo_fd_login.set_text("")
     self.ilo_fd_passwd.set_text("")
     self.ilo_fd_hostname.set_text("")
+    self.rsa_fd_name.set_text("")
+    self.rsa_fd_login.set_text("")
+    self.rsa_fd_passwd.set_text("")
+    self.rsa_fd_hostname.set_text("")
     self.drac_fd_name.set_text("")
     self.drac_fd_login.set_text("")
     self.drac_fd_passwd.set_text("")
     self.drac_fd_ip.set_text("")
+    self.rsa_fd_name.set_text("")
+    self.rsa_fd_login.set_text("")
+    self.rsa_fd_passwd.set_text("")
+    self.rsa_fd_ip.set_text("")
     self.vixel_fd_name.set_text("")
     self.vixel_fd_ip.set_text("")
     self.vixel_fd_passwd.set_text("")
@@ -328,6 +413,7 @@ class FenceHandler:
     self.ipmilan_fd_login.set_text("")
     self.ipmilan_fd_passwd.set_text("")
     self.ipmilan_fd_ip.set_text("")
+    self.ipmilan_fd_auth.set_text("none")
     self.bullpap_fd_name.set_text("")
     self.bullpap_fd_login.set_text("")
     self.bullpap_fd_passwd.set_text("")
@@ -340,12 +426,23 @@ class FenceHandler:
     self.apc_fd_login.set_text(attrs["login"])
     self.apc_fd_passwd.set_text(attrs["passwd"])
 
- 
+  def pop_apc_snmp_fd(self, attrs):
+    self.apc_snmp_fd_name.set_text(attrs["name"]) 
+    self.apc_snmp_fd_ip.set_text(attrs["ipaddr"])
+    self.apc_snmp_fd_login.set_text(attrs["login"])
+    self.apc_snmp_fd_passwd.set_text(attrs["passwd"])
+
   def pop_wti_fd(self, attrs):
     self.wti_fd_ip.set_text(attrs["ipaddr"])
     self.wti_fd_name.set_text(attrs["name"])
     self.wti_fd_passwd.set_text(attrs["passwd"])
  
+  def pop_rps10_fd(self, attrs):
+    self.rps10_fd_name.set_text(attrs["name"])
+    self.rps10_fd_device.set_text(attrs["device"])
+    self.rps10_fd_port.set_text(attrs["port"])
+
+
   def pop_brocade_fd(self, attrs):
     self.brocade_fd_name.set_text(attrs["name"])
     self.brocade_fd_ip.set_text(attrs["ipaddr"])
@@ -359,12 +456,24 @@ class FenceHandler:
     self.ilo_fd_passwd.set_text(attrs["passwd"])
     self.ilo_fd_hostname.set_text(attrs["hostname"])
 
+  def pop_rsa_fd(self, attrs):
+    self.rsa_fd_name.set_text(attrs["name"])
+    self.rsa_fd_login.set_text(attrs["login"])
+    self.rsa_fd_passwd.set_text(attrs["passwd"])
+    self.rsa_fd_hostname.set_text(attrs["hostname"])
+
   def pop_drac_fd(self, attrs):
     self.drac_fd_name.set_text(attrs["name"])
     self.drac_fd_login.set_text(attrs["login"])
     self.drac_fd_passwd.set_text(attrs["passwd"])
     self.drac_fd_ip.set_text(attrs["ipaddr"])
 
+  def pop_rsa_fd(self, attrs):
+    self.rsa_fd_name.set_text(attrs["name"])
+    self.rsa_fd_login.set_text(attrs["login"])
+    self.rsa_fd_passwd.set_text(attrs["passwd"])
+    self.rsa_fd_ip.set_text(attrs["ipaddr"])
+
  
   def pop_vixel_fd(self, attrs):
     self.vixel_fd_name.set_text(attrs["name"])
@@ -409,6 +518,10 @@ class FenceHandler:
     self.ipmilan_fd_login.set_text(attrs["login"])
     self.ipmilan_fd_passwd.set_text(attrs["passwd"])
     self.ipmilan_fd_ip.set_text(attrs["ipaddr"])
+    try:
+      self.ipmilan_fd_auth.set_text(attrs["auth"])
+    except KeyError, e:
+      self.ipmilan_fd_auth.set_text("")
 
   def pop_bullpap_fd(self, attrs):
     self.bullpap_fd_name.set_text(attrs["name"])
@@ -421,16 +534,23 @@ class FenceHandler:
     ##Fence Instance Form Fields
     self.apc_port = self.fence_xml.get_widget('entry1') 
     self.apc_switch = self.fence_xml.get_widget('entry2') 
+    self.apc_snmp_port = self.fence_xml.get_widget('apc_snmp_entry1') 
+    self.apc_snmp_switch = self.fence_xml.get_widget('apc_snmp_entry2') 
     self.wti_port = self.fence_xml.get_widget('entry3') 
     self.brocade_port = self.fence_xml.get_widget('entry4') 
     self.vixel_port = self.fence_xml.get_widget('entry5') 
     self.ilo_port = self.fence_xml.get_widget('entry7') 
+    self.rsa_port = self.fence_xml.get_widget('rsa_entry1') 
     self.sanbox2_port = self.fence_xml.get_widget('entry8') 
     self.bladecenter_blade = self.fence_xml.get_widget('entry41') 
     self.mcdata_port = self.fence_xml.get_widget('entry9') 
     self.egenera_lpan = self.fence_xml.get_widget('entry10') 
     self.egenera_pserver = self.fence_xml.get_widget('entry11')
     self.bullpap_domain = self.fence_xml.get_widget('entry51') 
+    self.drac_modname_label = self.fence_xml.get_widget('label108')
+    self.drac_modulename = self.fence_xml.get_widget('entry69')
+    self.drac_mc_cbox = self.fence_xml.get_widget('drac_mc_cbox')
+    self.drac_mc_cbox.connect('toggled',self.on_drac_mc_cbox_changed)
 
     ##Fence Device Forms
     self.apc_fd_name = self.fence_xml.get_widget('entry12')
@@ -438,10 +558,19 @@ class FenceHandler:
     self.apc_fd_login = self.fence_xml.get_widget('entry14')
     self.apc_fd_passwd = self.fence_xml.get_widget('entry15')
 
+    self.apc_snmp_fd_name = self.fence_xml.get_widget('apc_snmp_entry3')
+    self.apc_snmp_fd_ip = self.fence_xml.get_widget('apc_snmp_entry4')
+    self.apc_snmp_fd_login = self.fence_xml.get_widget('apc_snmp_entry5')
+    self.apc_snmp_fd_passwd = self.fence_xml.get_widget('apc_snmp_entry6')
+
     self.wti_fd_ip = self.fence_xml.get_widget('entry17')
     self.wti_fd_name = self.fence_xml.get_widget('entry16')
     self.wti_fd_passwd = self.fence_xml.get_widget('entry18')
 
+    self.rps10_fd_name = self.fence_xml.get_widget('entry61')
+    self.rps10_fd_device = self.fence_xml.get_widget('entry62')
+    self.rps10_fd_port = self.fence_xml.get_widget('entry63')
+
     self.brocade_fd_name = self.fence_xml.get_widget('entry19')
     self.brocade_fd_ip = self.fence_xml.get_widget('entry20')
     self.brocade_fd_login = self.fence_xml.get_widget('entry21')
@@ -459,11 +588,21 @@ class FenceHandler:
     self.ilo_fd_passwd = self.fence_xml.get_widget('entry30')
     self.ilo_fd_hostname = self.fence_xml.get_widget('entry31')
 
+    self.rsa_fd_name = self.fence_xml.get_widget('rsa_entry2')
+    self.rsa_fd_login = self.fence_xml.get_widget('rsa_entry3')
+    self.rsa_fd_passwd = self.fence_xml.get_widget('rsa_entry4')
+    self.rsa_fd_hostname = self.fence_xml.get_widget('rsa_entry5')
+
     self.drac_fd_name = self.fence_xml.get_widget('entry57')
     self.drac_fd_login = self.fence_xml.get_widget('entry59')
     self.drac_fd_passwd = self.fence_xml.get_widget('entry60')
     self.drac_fd_ip = self.fence_xml.get_widget('entry58')
 
+    self.rsa_fd_name = self.fence_xml.get_widget('entry64')
+    self.rsa_fd_login = self.fence_xml.get_widget('entry66')
+    self.rsa_fd_passwd = self.fence_xml.get_widget('entry67')
+    self.rsa_fd_ip = self.fence_xml.get_widget('entry65')
+
     self.sanbox2_fd_name = self.fence_xml.get_widget('entry32')
     self.sanbox2_fd_ip = self.fence_xml.get_widget('entry33')
     self.sanbox2_fd_login = self.fence_xml.get_widget('entry46')
@@ -488,6 +627,7 @@ class FenceHandler:
     self.ipmilan_fd_ip = self.fence_xml.get_widget('entry48')
     self.ipmilan_fd_login = self.fence_xml.get_widget('entry49')
     self.ipmilan_fd_passwd = self.fence_xml.get_widget('entry50')
+    self.ipmilan_fd_auth = self.fence_xml.get_widget('entry68')
 
     self.bullpap_fd_name = self.fence_xml.get_widget('entry56')
     self.bullpap_fd_ip = self.fence_xml.get_widget('entry52')
@@ -536,6 +676,34 @@ class FenceHandler:
 
     return fields
  
+  def val_apc_snmp_fd(self, name):
+    rectify_fence_name = False
+    if self.apc_snmp_fd_name.get_text() == "":
+      raise ValidationError('FATAL', FD_PROVIDE_NAME)
+    self.validateNCName(self.apc_snmp_fd_name)
+    if name != self.apc_snmp_fd_name.get_text():
+      res = self.check_unique_fd_name(self.apc_snmp_fd_name.get_text())
+      if res == False:  #name is already used
+        raise ValidationError('FATAL', FD_PROVIDE_NAME)
+      rectify_fence_name = True
+    
+    if self.apc_snmp_fd_ip.get_text() == "":
+        raise ValidationError('FATAL', FD_PROVIDE_IP)
+    if self.apc_snmp_fd_login.get_text() == "":
+        raise ValidationError('FATAL', FD_PROVIDE_LOGIN)
+    if self.apc_snmp_fd_passwd.get_text() == "":
+        raise ValidationError('FATAL', FD_PROVIDE_PASSWD)
+
+    if rectify_fence_name == True:
+      self.model_builder.rectifyNewFencedevicenameWithFences(name,self.apc_snmp_fd_name.get_text())
+
+    fields = {}
+    fields["name"] = self.apc_snmp_fd_name.get_text()
+    fields["ipaddr"] = self.apc_snmp_fd_ip.get_text()
+    fields["login"] = self.apc_snmp_fd_login.get_text()
+    fields["passwd"] = self.apc_snmp_fd_passwd.get_text()
+
+    return fields
  
   def val_wti_fd(self, name):
     rectify_fence_name = False
@@ -563,6 +731,32 @@ class FenceHandler:
 
     return fields
  
+  def val_rps10_fd(self, name):
+    rectify_fence_name = False
+    if self.rps10_fd_name.get_text() == "":
+      raise ValidationError('FATAL', FD_PROVIDE_NAME)
+    self.validateNCName(self.rps10_fd_name)
+    if name != self.rps10_fd_name.get_text():
+      res = self.check_unique_fd_name(self.rps10_fd_name.get_text())
+      if res == False:  #name is already used
+        raise ValidationError('FATAL', FD_PROVIDE_NAME)
+      rectify_fence_name = True
+
+    if self.rps10_fd_device.get_text() == "":
+        raise ValidationError('FATAL', FD_PROVIDE_DEVICE)
+    if self.rps10_fd_port.get_text() == "":
+        raise ValidationError('FATAL', FI_PROVIDE_PORT)
+
+    if rectify_fence_name == True:
+      self.model_builder.rectifyNewFencedevicenameWithFences(name,self.rps10_fd_name.get_text())
+
+    fields = {}
+    fields["name"] = self.rps10_fd_name.get_text()
+    fields["device"] = self.rps10_fd_device.get_text()
+    fields["port"] = self.rps10_fd_port.get_text()
+
+    return fields
+ 
  
   def val_brocade_fd(self, name):
     rectify_fence_name = False
@@ -623,6 +817,35 @@ class FenceHandler:
 
     return fields
  
+  def val_rsa_fd(self, name):
+    rectify_fence_name = False
+    if self.rsa_fd_name.get_text() == "":
+      raise ValidationError('FATAL', FD_PROVIDE_NAME)
+    self.validateNCName(self.rsa_fd_name)
+    if name != self.rsa_fd_name.get_text():
+      res = self.check_unique_fd_name(self.rsa_fd_name.get_text())
+      if res == False:  #name is already used
+        raise ValidationError('FATAL', FD_PROVIDE_NAME)
+      rectify_fence_name = True
+
+    if self.rsa_fd_login.get_text() == "":
+        raise ValidationError('FATAL', FD_PROVIDE_LOGIN)
+    if self.rsa_fd_passwd.get_text() == "":
+        raise ValidationError('FATAL', FD_PROVIDE_PASSWD)
+    if self.rsa_fd_hostname.get_text() == "":
+        raise ValidationError('FATAL', FD_PROVIDE_HOSTNAME)
+
+    if rectify_fence_name == True:
+      self.model_builder.rectifyNewFencedevicenameWithFences(name,self.rsa_fd_name.get_text())
+
+    fields = {}
+    fields["name"] = self.rsa_fd_name.get_text()
+    fields["hostname"] = self.rsa_fd_hostname.get_text()
+    fields["login"] = self.rsa_fd_login.get_text()
+    fields["passwd"] = self.rsa_fd_passwd.get_text()
+
+    return fields
+ 
  
   def val_drac_fd(self, name):
     rectify_fence_name = False
@@ -653,6 +876,36 @@ class FenceHandler:
 
     return fields
  
+  def val_rsa_fd(self, name):
+    rectify_fence_name = False
+    if self.rsa_fd_name.get_text() == "":
+      raise ValidationError('FATAL', FD_PROVIDE_NAME)
+    self.validateNCName(self.rsa_fd_name)
+    if name != self.rsa_fd_name.get_text():
+      res = self.check_unique_fd_name(self.rsa_fd_name.get_text())
+      if res == False:  #name is already used
+        raise ValidationError('FATAL', FD_PROVIDE_NAME)
+      rectify_fence_name = True
+
+    if self.rsa_fd_login.get_text() == "":
+        raise ValidationError('FATAL', FD_PROVIDE_LOGIN)
+    if self.rsa_fd_passwd.get_text() == "":
+        raise ValidationError('FATAL', FD_PROVIDE_PASSWD)
+    if self.rsa_fd_ip.get_text() == "":
+        raise ValidationError('FATAL', FD_PROVIDE_IP)
+
+    if rectify_fence_name == True:
+      self.model_builder.rectifyNewFencedevicenameWithFences(name,self.rsa_fd_name.get_text())
+
+    fields = {}
+    fields["name"] = self.rsa_fd_name.get_text()
+    fields["ipaddr"] = self.rsa_fd_ip.get_text()
+    fields["login"] = self.rsa_fd_login.get_text()
+    fields["passwd"] = self.rsa_fd_passwd.get_text()
+
+    return fields
+ 
+ 
  
   def val_vixel_fd(self, name):
     rectify_fence_name = False
@@ -869,6 +1122,8 @@ class FenceHandler:
     fields["ipaddr"] = self.ipmilan_fd_ip.get_text()
     fields["login"] = self.ipmilan_fd_login.get_text()
     fields["passwd"] = self.ipmilan_fd_passwd.get_text()
+    if self.ipmilan_fd_auth != "":
+      fields["auth"] = self.ipmilan_fd_auth.get_text()
 
     return fields
  
@@ -925,6 +1180,18 @@ class FenceHandler:
 
     return fields
 
+  def val_apc_snmp(self):
+    if self.apc_snmp_port.get_text() == "": 
+      raise ValidationError('FATAL', FI_PROVIDE_PORT)
+    if self.apc_snmp_switch.get_text() == "": 
+      raise ValidationError('FATAL', FI_PROVIDE_SWITCH)
+
+    fields = {}
+    fields["port"] = self.apc_snmp_port.get_text()
+    fields["switch"] = self.apc_snmp_switch.get_text()
+
+    return fields
+
   def val_wti(self):
     if self.wti_port.get_text() == "":
       raise ValidationError('FATAL', FI_PROVIDE_PORT)
@@ -934,6 +1201,12 @@ class FenceHandler:
 
     return fields
 
+  def val_rps10(self):
+
+    fields = {}
+
+    return fields
+
   def val_brocade(self):
     if self.brocade_port.get_text() == "":
       raise ValidationError('FATAL', FI_PROVIDE_PORT)
@@ -963,10 +1236,35 @@ class FenceHandler:
 
     return fields
 
+  def val_rsa(self):
+
+    fields = {}
+
+    return fields
+
   def val_drac(self):
 
     fields = {}
 
+    if self.drac_mc_cbox.get_active() == True:
+      modname = self.drac_modulename.get_text()
+      if modname == "":
+        raise ValidationError('FATAL', FI_PROVIDE_MODULENAME)
+
+      fields["modulename"] = modname
+    else:
+      fields["modulename"] = "" #This is done as a signal to ConfigTabController
+                                #code, so that in case a modname WAS set, and
+                                #then user unchecks the checkbox in an edit
+                                #situation, then the modname attr is removed
+                                #from the attrlist of the object in the model.
+
+    return fields
+
+  def val_rsa(self):
+
+    fields = {}
+
     return fields
 
   def val_sanbox2(self):
@@ -1075,4 +1373,12 @@ class FenceHandler:
       gtkentry.set_text(name)
       # select text
       raise ValidationError('FATAL', ILLEGAL_CHARS_REPLACED)
- 
+
+  def on_drac_mc_cbox_changed(self, *args):
+    if self.drac_mc_cbox.get_active() == True:
+      self.drac_modulename.set_sensitive(True)
+      self.drac_modname_label.set_sensitive(True)
+    else: 
+      self.drac_modulename.set_text("")
+      self.drac_modulename.set_sensitive(False)
+      self.drac_modname_label.set_sensitive(False)
