@@ -23,6 +23,7 @@ from Script import Script
 from NFSClient import NFSClient
 from NFSExport import NFSExport
 from Fs import Fs
+from Samba import Samba
 from Multicast import Multicast
 from FenceDaemon import FenceDaemon
 from Netfs import Netfs
@@ -57,6 +58,7 @@ TAGNAMES={ 'cluster':Cluster,
            'failoverdomainnode':FailoverDomainNode,
            'ip':Ip,
            'fs':Fs,
+           'smb':Samba,
            'fence_daemon':FenceDaemon,
            'multicast':Multicast,
            'clusterfs':Clusterfs,
@@ -82,7 +84,7 @@ CMAN_PTR_STR="cman"
 ###-----------------------------------
 
 
-INVALID_GULM_COUNT=_("GuLM locking mechanism may consist of 1, 3, 4 or 5 locking servers. You have configured %d. Fix the error and try saving again.")
+INVALID_GULM_COUNT=_("GULM locking mechanism may consist of 1, 3, 4 or 5 locking servers. You have configured %d. Fix the error and try saving again.")
 
 
 class ModelBuilder:
@@ -422,7 +424,7 @@ class ModelBuilder:
   def deleteNode(self, clusternode):
     #1) delete node
     #2) delete failoverdomainnodes with same name
-    #3) delete lockserver nodes if GuLM
+    #3) delete lockserver nodes if GULM
 
     name = clusternode.getName()
 
@@ -560,7 +562,7 @@ class ModelBuilder:
 
   def isNodeLockserver(self,name):
     gptr = self.getGULMPtr()
-    if gptr == None:  #Obviously not GuLM
+    if gptr == None:  #Obviously not GULM
       return False
     children = gptr.getChildren()
     for child in children:
@@ -571,7 +573,7 @@ class ModelBuilder:
 
   def removeLockserver(self, clusternode):
     gptr = self.getGULMPtr()
-    if gptr == None:  #Obviously not GuLM
+    if gptr == None:  #Obviously not GULM
       return
     children = gptr.getChildren()
     for child in children:
@@ -863,7 +865,11 @@ class ModelBuilder:
           break
           
     
- 
+  def searchObjectTree(self, tagtype):
+    objlist = list()
+    self.object_tree.searchTree(objlist, tagtype)
+
+    return objlist 
    
 if __name__ == "__main__":
   print "Starting main program"
