@@ -4,6 +4,7 @@ import gobject
 from clui_constants import *
 from RefObject import RefObject
 
+import cgi
 import gettext
 _ = gettext.gettext
 ### gettext first, then import gtk (exception prints gettext "_") ###
@@ -25,6 +26,14 @@ EXCLUSIVE_STR = "exclusive"
 
 AUTOSTART_STR = "autostart"
 
+RECOVERY_STR = "recovery"
+
+RESTART_STR = "restart"
+
+RELOCATE_STR = "relocate"
+
+DISABLE_STR = "disable"
+
 ###YUK! XXX make access to this static in ResourceHandler
 ###This is an awful copy
 RC_OPTS = {"ip":_("IP Address"),
@@ -116,6 +125,13 @@ class ServiceController:
     self.autostart_cbox = self.glade_xml.get_widget('autostart_cbox')
     self.autostart_cbox.connect('toggled',self.on_autostart_cbox_changed)
 
+    self.svc_restart_rbutton = self.glade_xml.get_widget('svc_restart')
+    self.svc_restart_rbutton.connect("toggled",self.on_recovery_radio_changed)
+    self.svc_relocate_rbutton = self.glade_xml.get_widget('svc_relocate')
+    self.svc_relocate_rbutton.connect("toggled",self.on_recovery_radio_changed)
+    self.svc_disable_rbutton = self.glade_xml.get_widget('svc_disable')
+    self.svc_disable_rbutton.connect("toggled",self.on_recovery_radio_changed)
+
     self.exclusive_cbox = self.glade_xml.get_widget('exclusive_cbox')
     self.exclusive_cbox.connect('toggled',self.on_exclusive_cbox_changed)
     self.rc_proxy = self.glade_xml.get_widget('svc_rc_proxy')
@@ -295,7 +311,7 @@ class ServiceController:
     
     self.current_service = svc
     if self.current_service != None:  
-      self.service_name_label.set_markup("<span><b>" + svc.getName() + "</b></span>")
+      self.service_name_label.set_markup("<span><b>" + cgi.escape(svc.getName()) + "</b></span>")
 
       #if necessary, set exclusive checkbox
       exclusive_state = svc.getAttribute(EXCLUSIVE_STR)
@@ -306,10 +322,26 @@ class ServiceController:
 
       #and if necessary, set autostart checkbox
       autostart_state = svc.getAttribute(AUTOSTART_STR)
-      if (autostart_state == None) or (autostart_state == "0"):
+      if (autostart_state == "0"):
         self.autostart_cbox.set_active(False)
       else:
         self.autostart_cbox.set_active(True)
+        if autostart_state == None:
+          self.current_service.addAttribute(AUTOSTART_STR,"1")
+
+      #We can't forget the radiogroup
+      recovery_attr = svc.getAttribute(RECOVERY_STR)
+      if recovery_attr != None:
+        recovery_attr = recovery_attr.lower()
+      if (recovery_attr == None) or (recovery_attr == RESTART_STR):
+        self.svc_restart_rbutton.set_active(True)
+      elif (recovery_attr == RELOCATE_STR):
+        self.svc_relocate_rbutton.set_active(True)
+      elif (recovery_attr == DISABLE_STR):
+        self.svc_disable_rbutton.set_active(True)
+      else:
+        self.svc_restart_rbutton.set_active(True)
+
 
       self.populate_fdom_optionmenu()
       self.prep_service_tree()
@@ -473,12 +505,22 @@ class ServiceController:
     if self.prepset == True:
       return
     self.model_builder.setModified()
-    if self.autostart_cbox.get_active() == True:
-      self.current_service.addAttribute(AUTOSTART_STR,"1")
+    if self.autostart_cbox.get_active() == False:
+      self.current_service.addAttribute(AUTOSTART_STR,"0")
     else:
       retval = self.current_service.getAttribute(AUTOSTART_STR)
       if retval != None:
         self.current_service.removeAttribute(AUTOSTART_STR)
+
+  def on_recovery_radio_changed(self, *args):
+    if self.svc_restart_rbutton.get_active() == True:
+      self.current_service.addAttribute(RECOVERY_STR, RESTART_STR)
+    elif self.svc_relocate_rbutton.get_active() == True:
+      self.current_service.addAttribute(RECOVERY_STR, RELOCATE_STR)
+    elif self.svc_disable_rbutton.get_active() == True:
+      self.current_service.addAttribute(RECOVERY_STR, DISABLE_STR)
+
+    self.model_builder.setModified()
                                                                                 
   def on_shared_rc_cancel(self, button):
     self.shared_rc_panel.hide()
